summaryrefslogtreecommitdiff
path: root/examples/echo_component.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/echo_component.py')
-rwxr-xr-xexamples/echo_component.py101
1 files changed, 42 insertions, 59 deletions
diff --git a/examples/echo_component.py b/examples/echo_component.py
index 9a24f2fa..664fe311 100755
--- a/examples/echo_component.py
+++ b/examples/echo_component.py
@@ -1,37 +1,26 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
SleekXMPP: The Sleek XMPP Library
Copyright (C) 2010 Nathanael C. Fritz
- This file is part of SleekXMPP.
+ This file is part of Slixmpp.
See the file LICENSE for copying permission.
"""
-import sys
import logging
-import getpass
-from optparse import OptionParser
+from getpass import getpass
+from argparse import ArgumentParser
-import sleekxmpp
-from sleekxmpp.componentxmpp import ComponentXMPP
-
-# Python versions before 3.0 do not use UTF-8 encoding
-# by default. To ensure that Unicode is handled properly
-# throughout SleekXMPP, we will set the default encoding
-# ourselves to UTF-8.
-if sys.version_info < (3, 0):
- from sleekxmpp.util.misc_ops import setdefaultencoding
- setdefaultencoding('utf8')
-else:
- raw_input = input
+import slixmpp
+from slixmpp.componentxmpp import ComponentXMPP
class EchoComponent(ComponentXMPP):
"""
A simple SleekXMPP component that echoes messages.
"""
def __init__(self, jid, secret, server, port):
@@ -67,56 +56,50 @@ class EchoComponent(ComponentXMPP):
if __name__ == '__main__':
# Setup the command line arguments.
- optp = OptionParser()
+ parser = ArgumentParser(description=EchoComponent.__doc__)
# Output verbosity options.
- optp.add_option('-q', '--quiet', help='set logging to ERROR',
- action='store_const', dest='loglevel',
- const=logging.ERROR, default=logging.INFO)
- optp.add_option('-d', '--debug', help='set logging to DEBUG',
- action='store_const', dest='loglevel',
- const=logging.DEBUG, default=logging.INFO)
- optp.add_option('-v', '--verbose', help='set logging to COMM',
- action='store_const', dest='loglevel',
- const=5, default=logging.INFO)
+ parser.add_argument("-q", "--quiet", help="set logging to ERROR",
+ action="store_const", dest="loglevel",
+ const=logging.ERROR, default=logging.INFO)
+ parser.add_argument("-d", "--debug", help="set logging to DEBUG",
+ action="store_const", dest="loglevel",
+ const=logging.DEBUG, default=logging.INFO)
# JID and password options.
- optp.add_option("-j", "--jid", dest="jid",
- help="JID to use")
- optp.add_option("-p", "--password", dest="password",
- help="password to use")
- optp.add_option("-s", "--server", dest="server",
- help="server to connect to")
- optp.add_option("-P", "--port", dest="port",
- help="port to connect to")
-
- opts, args = optp.parse_args()
-
- if opts.jid is None:
- opts.jid = raw_input("Component JID: ")
- if opts.password is None:
- opts.password = getpass.getpass("Password: ")
- if opts.server is None:
- opts.server = raw_input("Server: ")
- if opts.port is None:
- opts.port = int(raw_input("Port: "))
+ parser.add_argument("-j", "--jid", dest="jid",
+ help="JID to use")
+ parser.add_argument("-p", "--password", dest="password",
+ help="password to use")
+ parser.add_argument("-s", "--server", dest="server",
+ help="server to connect to")
+ parser.add_argument("-P", "--port", dest="port",
+ help="port to connect to")
+
+ args = parser.parse_args()
+
+ if args.jid is None:
+ args.jid = input("Component JID: ")
+ if args.password is None:
+ args.password = getpass("Password: ")
+ if args.server is None:
+ args.server = input("Server: ")
+ if args.port is None:
+ args.port = int(input("Port: "))
# Setup logging.
- logging.basicConfig(level=opts.loglevel,
+ logging.basicConfig(level=args.loglevel,
format='%(levelname)-8s %(message)s')
# Setup the EchoComponent and register plugins. Note that while plugins
# may have interdependencies, the order in which you register them does
# not matter.
- xmpp = EchoComponent(opts.jid, opts.password, opts.server, opts.port)
- xmpp.registerPlugin('xep_0030') # Service Discovery
- xmpp.registerPlugin('xep_0004') # Data Forms
- xmpp.registerPlugin('xep_0060') # PubSub
- xmpp.registerPlugin('xep_0199') # XMPP Ping
+ xmpp = EchoComponent(args.jid, args.password, args.server, args.port)
+ xmpp.register_plugin('xep_0030') # Service Discovery
+ xmpp.register_plugin('xep_0004') # Data Forms
+ xmpp.register_plugin('xep_0060') # PubSub
+ xmpp.register_plugin('xep_0199') # XMPP Ping
# Connect to the XMPP server and start processing XMPP stanzas.
- if xmpp.connect():
- xmpp.process(block=True)
- print("Done")
- else:
- print("Unable to connect.")
+ xmpp.connect()
+ xmpp.process()
@@ -1,37 +1,26 @@
# -*- coding: utf-8 -*-
"""
- SleekXMPP: The Sleek XMPP Library
+ Slixmpp: The Slick XMPP Library
Copyright (C) 2010 Nathanael C. Fritz
@@ -1,37 +1,26 @@
class EchoComponent(ComponentXMPP):
"""
- A simple SleekXMPP component that echoes messages.
+ A simple Slixmpp component that echoes messages.
"""
def __init__(self, jid, secret, server, port):